@@ -3,7 +3,7 @@ function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NULL,scores=FALSE
     n <- dim(r)[2]
     if (n!=dim(r)[1]) {  n.obs <- dim(r)[1]
                if(scores) {x.matrix <- r
-                  if(missing) {
+             if(missing) {     #impute values 
         miss <- which(is.na(x.matrix),arr.ind=TRUE)
         if(impute=="mean") {
        item.means <- colMeans(x.matrix,na.rm=TRUE)   #replace missing values with means
@@ -22,8 +22,7 @@ function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NULL,scores=FALSE
    
     r.mat <- r
      if(SMC) { 
-      if(nfactors < n/2) 
-        {diag(r.mat) <- smc(r) } } else {if (warnings) message("too many factors requested for this number of variables to use SMC, 1s used instead")}
+      if(nfactors < n/2)   {diag(r.mat) <- smc(r) }  else {if (warnings) message("too many factors requested for this number of variables to use SMC, 1s used instead")}  }
     orig <- diag(r)
    
    
@@ -48,7 +47,7 @@ function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NULL,scores=FALSE
          comm <- comm1
          comm.list[[i]] <- comm1
          i <- i + 1
-         if(i > max.iter) {message("maximum iteration exceeded")
+         if(i > max.iter) {if(warnings)  {message("maximum iteration exceeded")}
                 err <-0 }
        }
        # a weird condition that happens with the Eysenck data
@@ -70,6 +69,7 @@ function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NULL,scores=FALSE
     	} #sign of largest loading is positive
     	colnames(loadings) <- paste("PA",1:nfactors,sep='')
     rownames(loadings) <- rownames(r)
+    loadings[loadings==0.0] <- 10^-15    #added to stop a problem with varimax if loadings are exactly 0
     
     model <- loadings %*% t(loadings)  
     result$communality <- round(diag(model),digits)
@@ -121,7 +121,8 @@ function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NULL,scores=FALSE
     
     if(scores) {result$scores <- factor.scores(x.matrix,loadings) }
     result$factors <- nfactors 
-    class(result) <- "factanal"
+    result$fn <- "factor.pa"
+    class(result) <- c("factanal","psych")
     return(result) }
     
  
